@@ -112,7 +112,7 @@ __rpc_dtbsize()
 		return (tbsize);
 	}
 	if (getrlimit(RLIMIT_NOFILE, &rl) == 0) {
-		return (tbsize = (int)rl.rlim_max);
+		return (tbsize = (int)rl.rlim_cur);
 	}
 	/*
 	 * Something wrong.  I'll try to save face by returning a
@@ -213,7 +213,8 @@ getnettype(nettype)
 }
 
 /*
- * For the given nettype (tcp or udp only), return the first structure found.
+ * For the given nettype (tcp or udp only), return the first
+ * IPv4 structure found.
  * This should be freed by calling freenetconfigent()
  */
 struct netconfig *
@@ -250,8 +251,7 @@ __rpc_getconfip(nettype)
 			return (NULL);
 		}
 		while ((nconf = getnetconfig(confighandle)) != NULL) {
-			if (strcmp(nconf->nc_protofmly, NC_INET) == 0 ||
-			    strcmp(nconf->nc_protofmly, NC_INET6) == 0) {
+			if (strcmp(nconf->nc_protofmly, NC_INET) == 0) {
 				if (strcmp(nconf->nc_proto, NC_TCP) == 0 &&
 						netid_tcp == NULL) {
 					netid_tcp = strdup(nconf->nc_netid);
@@ -319,6 +319,7 @@ __rpc_setconf(nettype)
 		handle->nflag = FALSE;
 		break;
 	default:
+		free(handle);
 		return (NULL);
 	}
 
@@ -615,6 +616,9 @@ __rpc_taddr2uaddr_af(int af, const struct netbuf *nbuf)
 
 	switch (af) {
 	case AF_INET:
+		if (nbuf->len < sizeof(*sin)) {
+			return NULL;
+		}
 		sin = nbuf->buf;
 		if (inet_ntop(af, &sin->sin_addr, namebuf, sizeof namebuf)
 		    == NULL)
@@ -626,6 +630,9 @@ __rpc_taddr2uaddr_af(int af, const struct netbuf *nbuf)
 		break;
 #ifdef INET6
 	case AF_INET6:
+		if (nbuf->len < sizeof(*sin6)) {
+			return NULL;
+		}
 		sin6 = nbuf->buf;
 		if (inet_ntop(af, &sin6->sin6_addr, namebuf6, sizeof namebuf6)
 		    == NULL)
@@ -667,6 +674,8 @@ __rpc_uaddr2taddr_af(int af, const char *uaddr)
 
 	port = 0;
 	sin = NULL;
+	if (uaddr == NULL)
+		return NULL;
 	addrstr = strdup(uaddr);
 	if (addrstr == NULL)
 		return NULL;
